## TODO (by desc. priority)
- Add per-cluster core-h accounting function
- Adding heartbeats from process itself (by stdout, stderr)
- Adding dependencies
- Implement periodic health check as a safeguard (move away from NodeManagers)
- Adding Resource system
- Adding notifications API
- Specify set of possible clusters for runs, with some prioritization system
- Add web UI

## Specs: Scheduling Priority
- (TODO) Run-specific priority
- (TODO) Experiment-specific priority
- (TODO) Expected runtime
- First scheduled